dnl Licensed under the Apache License, Version 2.0 (the "License");
dnl you may not use this file except in compliance with the License.
dnl You may obtain a copy of the License at
dnl 
dnl     http://www.apache.org/licenses/LICENSE-2.0
dnl 
dnl Unless required by applicable law or agreed to in writing, software
dnl distributed under the License is distributed on an "AS IS" BASIS,
dnl WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
dnl See the License for the specific language governing permissions and
dnl limitations under the License.
dnl 
dnl Authors:
dnl 2010-
dnl     Oscar Koeroo <okoeroo@nikhef.nl>
dnl     Mischa Sall\'e <msalle@nikhef.nl>
dnl     NIKHEF Amsterdam, the Netherlands
dnl
dnl Usage: AC_JOBREP_API
dnl  sets *_CFLAGS and *_LIBS

AC_DEFUN([AC_JOBREP_API],
[
    AC_ARG_WITH([jobrep-api-prefix],
		[AC_HELP_STRING([--with-jobrep-api-prefix=DIR],
		    [Prefix where jobrep-api is installed (default /usr)])],
		[ac_jobrep_api_prefix=$withval],
		[ac_jobrep_api_prefix=/usr])

    AC_ARG_WITH([jobrep-api-libdir],
                [AC_HELP_STRING([--with-jobrep-api-libdir=DIR],
                    [Directory where jobrep-api libraries are installed (default either JOBREP-API-PREFIX/lib or JOBREP-API-PREFIX/lib64)])],
                [ac_jobrep_api_libdir=$withval],
                [])

    AC_ARG_WITH([jobrep-api-includes],
                [AC_HELP_STRING([--with-jobrep-api-includes=DIR],
                    [Directory where jobrep-api headers are installed (default JOBREP-API-PREFIX/include)])],
                [ac_jobrep_api_includes=$withval],
                [ac_jobrep_api_includes=$ac_jobrep_api_prefix/include])


    if test "x$with_jobrep_api_prefix" = "x" ; then
	PKG_CHECK_MODULES(JOBREP_API, jobrep-api, have_jobrep_api=yes, have_jobrep_api=no)
	if test "$have_jobrep_api" = "no" ; then
	    JOBREP_API_DIRECT_CHECK(JOBREP_API, have_jobrep_api=yes, have_jobrep_api=no)
	fi
    else
	JOBREP_API_DIRECT_CHECK(JOBREP_API, have_jobrep_api=yes, have_jobrep_api=no)
	if test "$have_jobrep_api" = "no" ; then
	    PKG_CHECK_MODULES(JOBREP_API, jobrep-api, have_jobrep_api=yes, have_jobrep_api=no)
	fi
    fi
    
    AC_SUBST(JOBREP_API_CFLAGS)
    AC_SUBST(JOBREP_API_LIBS)
])    

AC_DEFUN([JOBREP_API_DIRECT_CHECK],
[
    ac_save_LIBS=$LIBS
    ac_save_CFLAGS=$CFLAGS

    if test "x$ac_jobrep_api_includes" != "x" ; then
        ac_try_CFLAGS="-I$ac_jobrep_api_includes"
    fi

    # check whether we have specified libdir otherwise specified a prefix
    if test "x$ac_jobrep_api_libdir" != "x" -o "x$with_jobrep_api_prefix" != "x" ; then
	# If we haven't specified/determined a libdir, do it now from prefix
        if test "x$ac_jobrep_api_libdir" = "x" ; then
	    if test "x$host_cpu" = "xx86_64" \
	     -a -e $with_jobrep_api_prefix/lib64 \
	     -a ! -h $with_jobrep_api_prefix/lib64 ; then
		ac_jobrep_api_libdir="$ac_jobrep_api_prefix/lib64"
	    else
		ac_jobrep_api_libdir="$ac_jobrep_api_prefix/lib"
	    fi
	fi    

	if test "x$LD_LIBRARY_PATH" != "x" ; then
            ac_save_LD_LIBRARY_PATH=$LD_LIBRARY_PATH
            export LD_LIBRARY_PATH="$ac_jobrep_api_libdir:$LD_LIBRARY_PATH"
        else
            export LD_LIBRARY_PATH="$ac_jobrep_api_libdir"
        fi

        if test "x$DYLD_LIBRARY_PATH" != "x" ; then
            ac_save_DYLD_LIBRARY_PATH=$DYLD_LIBRARY_PATH
            export DYLD_LIBRARY_PATH="$ac_jobrep_api_libdir:$DYLD_LIBRARY_PATH"
        else
            export DYLD_LIBRARY_PATH="$ac_jobrep_api_libdir"
        fi

	ac_try_LIBS="-lssl -L$ac_jobrep_api_libdir -ljobrep_api"
	AC_MSG_CHECKING([for $1 at system default and $ac_jobrep_api_prefix])
    else
	ac_try_LIBS="-lssl -ljobrep_api"
	AC_MSG_CHECKING([for $1 at system default])
    fi

    dnl We want to add the cmdline specified CFLAGS and LIBS, but only for
    dnl checking, not to the *_CFLAGS etc.
    CFLAGS="$ac_try_CFLAGS $CFLAGS"
    LIBS="$ac_try_LIBS $LIBS"
    AC_LINK_IFELSE( [#include <jobrepository/jobrep_api.h>
		     int main(void) {return 0;}],
                    [have_mod=yes], [have_mod=no])
    AC_MSG_RESULT([$have_mod])

    if test "x$have_mod" = "xyes" ; then
	[$2]
	$1_CFLAGS=$ac_try_CFLAGS
	$1_LIBS="$ac_try_LIBS"
    else
	[$3]
	$1_CFLAGS=""
	$1_LIBS=""
    fi

    CFLAGS=$ac_save_CFLAGS
    CPPFLAGS=$ac_save_CPPFLAGS
    LIBS=$ac_save_LIBS

    if test "x$ac_save_LD_LIBRARY_PATH" = "x" ; then
	unset LD_LIBRARY_PATH
    else
	LD_LIBRARY_PATH=$ac_save_LD_LIBRARY_PATH
    fi
    if test "x$ac_save_DYLD_LIBRARY_PATH" = "x" ; then
	unset DYLD_LIBRARY_PATH
    else
	DYLD_LIBRARY_PATH=$ac_save_DYLD_LIBRARY_PATH
    fi
    if test "x$ac_save_LD_LIBRARY_PATH" = "x" ; then
        unset LD_LIBRARY_PATH
    else
        LD_LIBRARY_PATH=$ac_save_LD_LIBRARY_PATH
    fi
    if test "x$ac_save_DYLD_LIBRARY_PATH" = "x" ; then
        unset DYLD_LIBRARY_PATH
    else
        DYLD_LIBRARY_PATH=$ac_save_DYLD_LIBRARY_PATH
    fi

])
